@@ -1,8 +1,8 @@
 ;;; timu-line.el --- Custom and simple mode line -*- lexical-binding: t; -*-
 
 ;; Author: Aimé Bertrand <aime.bertrand@macowners.club>
-;; Package-Version: 1.5
-;; Package-Revision: b2ad1e2353b2
+;; Package-Version: 1.6
+;; Package-Revision: 9ba731bd947b
 ;; Package-Requires: ((emacs "29.1"))
 ;; Created: 2023-07-31
 ;; Keywords: modeline frames ui
@@ -62,7 +62,9 @@
 ;;      - Display evil state
 ;;      - Display Tramp host if applicable
 ;;      - Display buffer/file name
+;;      - Display keybindings hint for the wdired buffer
 ;;      - Display keybindings hint for the org capture buffer
+;;      - Display keybindings hint for the org log note buffer
 ;;      - Display keybindings hint for the git commit message buffer
 ;;      - Display keybindings hint for the forge post buffer
 ;;      - Display the vc branch
@@ -104,6 +106,7 @@
 ;;      - `timu-line-show-python-virtual-env' - default value is t
 ;;      - `timu-line-show-wdired-keys' - default value is nil
 ;;      - `timu-line-show-org-capture-keys' - default value is t
+;;      - `timu-line-show-org-log-note-keys' - default value is nil
 ;;      - `timu-line-show-git-commit-keys' - default value is t
 ;;      - `timu-line-show-forge-post-keys' - default value is t
 ;;      - `timu-line-show-mu4e-context' - default value is t
@@ -229,6 +232,18 @@ This is set to \"t\" by default."
   :type 'string
   :group 'timu-line)
 
+(defcustom timu-line-show-org-log-note-keys nil
+  "Control whether to show the org log note keybindings in the mode line.
+This is set to \"nil\" by default."
+  :type 'boolean
+  :group 'timu-line)
+
+(defcustom timu-line-org-log-note-keys-string
+  "| Finish: M-s | Cancel: M-w |"
+  "The string to show as org log note keybindings."
+  :type 'string
+  :group 'timu-line)
+
 (defcustom timu-line-show-git-commit-keys t
   "Control whether to show the git commit message keybindings in the mode line.
 This is set to \"t\" by default."
@@ -425,14 +440,15 @@ This is however usefull for some section like the column number."
         (directory-file-name
          (file-name-parent-directory buffer-file-name)))
        "/"
-       (file-name-nondirectory
-        (directory-file-name buffer-file-name)))
+       (buffer-name))
     (buffer-name)))
 
 (defun timu-line-get-short-dired-path ()
   "Return the Dired's \"parent-directory/directory-name\" or \"/\" as a string.
 The value is \"/\" when `dired-directory' is at the root of the files system."
   (cond
+   ((listp dired-directory)
+    (buffer-name)) ;; FIXME Workaround for denote
    ((or (equal "/" dired-directory) (equal "/../" dired-directory))
     "/")
    ((timu-line-tramp-root-directory-p default-directory)
@@ -491,6 +507,18 @@ The value is \"/\" when `dired-directory' is at the root of the files system."
       "")
     'face face)))
 
+(defun timu-line-org-log-note-keys ()
+  "Return keybindings instruction for org log note as a propertized string."
+  (timu-line-face-switcher
+   'timu-line-fancy-face 'timu-line-inactive-face
+   (propertize
+    (if timu-line-show-org-log-note-keys
+        (if (bound-and-true-p timu-org-note-mode)
+            (concat "  " timu-line-org-log-note-keys-string " ")
+          "")
+      "")
+    'face face)))
+
 (defun timu-line-git-commit-keys ()
   "Return keybindings hint for git commit message as a propertized string."
   (timu-line-face-switcher
@@ -561,12 +589,11 @@ The value is \"/\" when `dired-directory' is at the root of the files system."
    'timu-line-special-face 'timu-line-inactive-face
    (propertize
     (if timu-line-show-vc-branch
-        (if vc-mode
+        (if (and (vc-root-dir)
+                 (or vc-mode (derived-mode-p 'dired-mode)))
             (let ((backend (vc-backend buffer-file-name)))
               (concat "  b:"
-                      (substring-no-properties
-                       vc-mode
-                       (+ (if (eq backend 'Hg) 2 3) 2))))
+                      (car (vc-git-branches))))
           "")
       "")
     'face face)))
@@ -659,8 +686,11 @@ The display it controlled by `timu-line-show-mu4e-index-update-indicator'."
                      "")
                  "")))
           (concat " e:"
-                  (shell-command-to-string
-                   "printf $(mu find flag:unread 2> /dev/null | wc -l)")
+                  (condition-case nil
+                      ;; TODO - for now catch error when visiting orphaned files
+                      (shell-command-to-string
+                       "printf $(mu find flag:unread 2> /dev/null | wc -l)")
+                    (error "err"))
                   (format "%s" mu4e-index-update-indicator)))
       "")
     'face face)))
@@ -824,6 +854,7 @@ aligned respectively."
                             (timu-line-vc-branch)
                             (timu-line-python-virtual-env)
                             (timu-line-org-capture-keys)
+                            (timu-line-org-log-note-keys)
                             (timu-line-git-commit-keys)
                             (timu-line-wdired-keys)
                             (timu-line-forge-post-keys)
